@@ -20,7 +20,7 @@
 // margin on the sides of message box
 static const int MARGIN = 15;
 // offset of message from start of the scene
-static const int SHOW_OFFSET = 5;
+static const int SHOW_OFFSET = 15;
 // space between pixmap and text
 static const int SOME_SPACE = 10;
 // width of the border in pixels
@@ -99,7 +99,15 @@ public:
     /**
      * Holds bounding rect of an item
      */
-    QRectF m_boundRect;
+    QRect m_boundRect;
+    /**
+     * Holds bounding rect of an item (mapped to scene coordinates)
+     */
+    QRectF m_mappedBoundRect;
+    /**
+     * Offset of message from start of the scene (mapped to scene coordinates)
+     */
+    qreal m_mapped_SHOW_OFFSET;
     /**
      * Position where item will appear
      */
@@ -214,7 +222,7 @@ void KGamePopupItem::paint( QPainter* p, const QStyleOptionGraphicsItem *option,
     }
     p->setBrush(widget ? d->m_brush.brush(widget->palette()) : QBrush());
     p->drawPath(d->m_path);
-    p->drawPixmap( MARGIN, static_cast<int>(d->m_boundRect.height()/2) - d->m_iconPix.height()/2,
+    p->drawPixmap( MARGIN, static_cast<int>(d->m_boundRect.height()/2) - d->m_iconPix.height()/2.0/d->m_iconPix.devicePixelRatio(),
                    d->m_iconPix );
     p->restore();
 }
@@ -259,13 +267,14 @@ void KGamePopupItem::showMessage( const QString& text, Position pos, ReplaceMode
     prepareGeometryChange();
 
     // recalculate bounding rect
-    qreal w = d->m_textChildItem->boundingRect().width()+MARGIN*2+d->m_iconPix.width()+SOME_SPACE;
+    const qreal iconDpr = d->m_iconPix.devicePixelRatio();
+    qreal w = d->m_textChildItem->boundingRect().width()+MARGIN*2+d->m_iconPix.width()/iconDpr+SOME_SPACE;
     qreal h = d->m_textChildItem->boundingRect().height()+MARGIN*2;
-    if( d->m_iconPix.height() > h )
+    if( d->m_iconPix.height()/iconDpr > h )
     {
-        h = d->m_iconPix.height() + MARGIN*2;
+        h = d->m_iconPix.height()/iconDpr + MARGIN*2;
 	}
-    d->m_boundRect = QRectF(0, 0, w, h);
+    d->m_boundRect = QRect(0, 0, w, h);
 
     // adjust to take into account the width of the pen
     // used to draw the border
@@ -275,6 +284,9 @@ void KGamePopupItem::showMessage( const QString& text, Position pos, ReplaceMode
                             borderRadius ,
                             borderRadius );
 
+    d->m_mappedBoundRect = sceneView->mapToScene(d->m_boundRect).boundingRect();
+    d->m_mapped_SHOW_OFFSET = qAbs(sceneView->mapToScene(0, SHOW_OFFSET).y());
+
     QPainterPath roundRectPath;
     roundRectPath.moveTo(w, d->m_sharpness);
     roundRectPath.arcTo(w-(2*d->m_sharpness), 0.0,(2*d->m_sharpness), (d->m_sharpness), 0.0, 90.0);
@@ -313,23 +325,23 @@ void KGamePopupItem::setupTimeline()
     d->m_timeLine.setDuration(300);
     if( d->m_position == TopLeft || d->m_position == TopRight )
     {
-        int start = static_cast<int>(d->m_visibleSceneRect.top() - d->m_boundRect.height() - SHOW_OFFSET);
-        int end = static_cast<int>(d->m_visibleSceneRect.top() + SHOW_OFFSET);
+        int start = static_cast<int>(d->m_visibleSceneRect.top() - d->m_mappedBoundRect.height() - d->m_mapped_SHOW_OFFSET);
+        int end = static_cast<int>(d->m_visibleSceneRect.top() + d->m_mapped_SHOW_OFFSET);
         d->m_timeLine.setFrameRange( start, end );
     }
     else if( d->m_position == BottomLeft || d->m_position == BottomRight )
     {
-        int start = static_cast<int>(d->m_visibleSceneRect.bottom()+SHOW_OFFSET);
-        int end = static_cast<int>(d->m_visibleSceneRect.bottom() - d->m_boundRect.height() - SHOW_OFFSET);
+        int start = static_cast<int>(d->m_visibleSceneRect.bottom() + d->m_mapped_SHOW_OFFSET);
+        int end = static_cast<int>(d->m_visibleSceneRect.bottom() - d->m_mappedBoundRect.height() - d->m_mapped_SHOW_OFFSET);
         d->m_timeLine.setFrameRange( start, end );
     }
     else if( d->m_position == Center )
     {
         d->m_timeLine.setFrameRange(0, d->m_timeLine.duration());
         setPos( d->m_visibleSceneRect.left() +
-                d->m_visibleSceneRect.width()/2 - d->m_boundRect.width()/2,
+                d->m_visibleSceneRect.width()/2 - d->m_mappedBoundRect.width()/2,
                 d->m_visibleSceneRect.top() +
-                d->m_visibleSceneRect.height()/2 - d->m_boundRect.height()/2);
+                d->m_visibleSceneRect.height()/2 - d->m_mappedBoundRect.height()/2);
     }
 
 }
@@ -338,11 +350,11 @@ void KGamePopupItem::animationFrame(int frame)
 {
     if( d->m_position == TopLeft || d->m_position == BottomLeft )
     {
-        setPos( d->m_visibleSceneRect.left()+SHOW_OFFSET, frame );
+        setPos( d->m_visibleSceneRect.left()+d->m_mapped_SHOW_OFFSET, frame );
     }
     else if( d->m_position == TopRight || d->m_position == BottomRight )
     {
-        setPos( d->m_visibleSceneRect.right()-d->m_boundRect.width()-SHOW_OFFSET, frame );
+        setPos( d->m_visibleSceneRect.right()-d->m_mappedBoundRect.width()-d->m_mapped_SHOW_OFFSET, frame );
     }
     else if( d->m_position == Center )
     {
@@ -421,7 +433,7 @@ void KGamePopupItem::hoverLeaveEvent( QGraphicsSceneHoverEvent* )
 void KGamePopupItem::setMessageIcon( const QPixmap& pix )
 {
     d->m_iconPix = pix;
-    d->m_textChildItem->setPos( MARGIN+pix.width()+SOME_SPACE, MARGIN );
+    d->m_textChildItem->setPos( MARGIN+pix.width()/pix.devicePixelRatio()+SOME_SPACE, MARGIN );
     // bounding rect is updated in showMessage()
 }
 
